==> cloudwatch-1.115.0-sources.jar: software/amazon/awscdk/services/cloudwatch/CfnInsightRuleProps.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * Properties for defining a `AWS::CloudWatch::InsightRule`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T15:55:57.891Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.CfnInsightRuleProps")
@software.amazon.jsii.Jsii.Proxy(CfnInsightRuleProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnInsightRuleProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::CloudWatch::InsightRule.RuleBody`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRuleBody();

    /**
     * `AWS::CloudWatch::InsightRule.RuleName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRuleName();

    /**
     * `AWS::CloudWatch::InsightRule.RuleState`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRuleState();

    /**
     * `AWS::CloudWatch::InsightRule.Tags`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnInsightRuleProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnInsightRuleProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnInsightRuleProps> {
        private java.lang.String ruleBody;
        private java.lang.String ruleName;
        private java.lang.String ruleState;
        private java.lang.Object tags;

        /**
         * Sets the value of {@link CfnInsightRuleProps#getRuleBody}
         * @param ruleBody `AWS::CloudWatch::InsightRule.RuleBody`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ruleBody(java.lang.String ruleBody) {
            this.ruleBody = ruleBody;
            return this;
        }

        /**
         * Sets the value of {@link CfnInsightRuleProps#getRuleName}
         * @param ruleName `AWS::CloudWatch::InsightRule.RuleName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ruleName(java.lang.String ruleName) {
            this.ruleName = ruleName;
            return this;
        }

        /**
         * Sets the value of {@link CfnInsightRuleProps#getRuleState}
         * @param ruleState `AWS::CloudWatch::InsightRule.RuleState`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ruleState(java.lang.String ruleState) {
            this.ruleState = ruleState;
            return this;
        }

        /**
         * Sets the value of {@link CfnInsightRuleProps#getTags}
         * @param tags `AWS::CloudWatch::InsightRule.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tags(software.amazon.awscdk.core.IResolvable tags) {
            this.tags = tags;
            return this;
        }

        /**
         * Sets the value of {@link CfnInsightRuleProps#getTags}
         * @param tags `AWS::CloudWatch::InsightRule.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tags(java.util.List<? extends java.lang.Object> tags) {
            this.tags = tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnInsightRuleProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnInsightRuleProps build() {
            return new Jsii$Proxy(ruleBody, ruleName, ruleState, tags);
        }
    }

    /**
     * An implementation for {@link CfnInsightRuleProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnInsightRuleProps {
        private final java.lang.String ruleBody;
        private final java.lang.String ruleName;
        private final java.lang.String ruleState;
        private final java.lang.Object tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ruleBody = software.amazon.jsii.Kernel.get(this, "ruleBody", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.ruleName = software.amazon.jsii.Kernel.get(this, "ruleName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.ruleState = software.amazon.jsii.Kernel.get(this, "ruleState", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String ruleBody, final java.lang.String ruleName, final java.lang.String ruleState, final java.lang.Object tags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ruleBody = java.util.Objects.requireNonNull(ruleBody, "ruleBody is required");
            this.ruleName = java.util.Objects.requireNonNull(ruleName, "ruleName is required");
            this.ruleState = java.util.Objects.requireNonNull(ruleState, "ruleState is required");
            this.tags = tags;
        }

        @Override
        public final java.lang.String getRuleBody() {
            return this.ruleBody;
        }

        @Override
        public final java.lang.String getRuleName() {
            return this.ruleName;
        }

        @Override
        public final java.lang.String getRuleState() {
            return this.ruleState;
        }

        @Override
        public final java.lang.Object getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("ruleBody", om.valueToTree(this.getRuleBody()));
            data.set("ruleName", om.valueToTree(this.getRuleName()));
            data.set("ruleState", om.valueToTree(this.getRuleState()));
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudwatch.CfnInsightRuleProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnInsightRuleProps.Jsii$Proxy that = (CfnInsightRuleProps.Jsii$Proxy) o;

            if (!ruleBody.equals(that.ruleBody)) return false;
            if (!ruleName.equals(that.ruleName)) return false;
            if (!ruleState.equals(that.ruleState)) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.ruleBody.hashCode();
            result = 31 * result + (this.ruleName.hashCode());
            result = 31 * result + (this.ruleState.hashCode());
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}

==> cloudwatch-1.173.0-sources.jar: software/amazon/awscdk/services/cloudwatch/CfnInsightRuleProps.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * Properties for defining a `CfnInsightRule`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.cloudwatch.*;
 * CfnInsightRuleProps cfnInsightRuleProps = CfnInsightRuleProps.builder()
 *         .ruleBody("ruleBody")
 *         .ruleName("ruleName")
 *         .ruleState("ruleState")
 *         // the properties below are optional
 *         .tags(List.of(CfnTag.builder()
 *                 .key("key")
 *                 .value("value")
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:27.206Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.CfnInsightRuleProps")
@software.amazon.jsii.Jsii.Proxy(CfnInsightRuleProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnInsightRuleProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The definition of the rule, as a JSON object.
     * <p>
     * For details about the syntax, see <a href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/ContributorInsights-RuleSyntax.html">Contributor Insights Rule Syntax</a> in the <em>Amazon CloudWatch User Guide</em> .
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRuleBody();

    /**
     * The name of the rule.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRuleName();

    /**
     * The current state of the rule.
     * <p>
     * Valid values are <code>ENABLED</code> and <code>DISABLED</code> .
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRuleState();

    /**
     * A list of key-value pairs to associate with the Contributor Insights rule.
     * <p>
     * You can associate as many as 50 tags with a rule.
     * <p>
     * Tags can help you organize and categorize your resources. For more information, see <a href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Tagging.html">Tagging Your Amazon CloudWatch Resources</a> .
     * <p>
     * To be able to associate tags with a rule, you must have the <code>cloudwatch:TagResource</code> permission in addition to the <code>cloudwatch:PutInsightRule</code> permission.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnInsightRuleProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnInsightRuleProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnInsightRuleProps> {
        java.lang.String ruleBody;
        java.lang.String ruleName;
        java.lang.String ruleState;
        java.lang.Object tags;

        /**
         * Sets the value of {@link CfnInsightRuleProps#getRuleBody}
         * @param ruleBody The definition of the rule, as a JSON object. This parameter is required.
         *                 For details about the syntax, see <a href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/ContributorInsights-RuleSyntax.html">Contributor Insights Rule Syntax</a> in the <em>Amazon CloudWatch User Guide</em> .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ruleBody(java.lang.String ruleBody) {
            this.ruleBody = ruleBody;
            return this;
        }

        /**
         * Sets the value of {@link CfnInsightRuleProps#getRuleName}
         * @param ruleName The name of the rule. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ruleName(java.lang.String ruleName) {
            this.ruleName = ruleName;
            return this;
        }

        /**
         * Sets the value of {@link CfnInsightRuleProps#getRuleState}
         * @param ruleState The current state of the rule. This parameter is required.
         *                  Valid values are <code>ENABLED</code> and <code>DISABLED</code> .
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ruleState(java.lang.String ruleState) {
            this.ruleState = ruleState;
            return this;
        }

        /**
         * Sets the value of {@link CfnInsightRuleProps#getTags}
         * @param tags A list of key-value pairs to associate with the Contributor Insights rule.
         *             You can associate as many as 50 tags with a rule.
         *             <p>
         *             Tags can help you organize and categorize your resources. For more information, see <a href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Tagging.html">Tagging Your Amazon CloudWatch Resources</a> .
         *             <p>
         *             To be able to associate tags with a rule, you must have the <code>cloudwatch:TagResource</code> permission in addition to the <code>cloudwatch:PutInsightRule</code> permission.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tags(software.amazon.awscdk.core.IResolvable tags) {
            this.tags = tags;
            return this;
        }

        /**
         * Sets the value of {@link CfnInsightRuleProps#getTags}
         * @param tags A list of key-value pairs to associate with the Contributor Insights rule.
         *             You can associate as many as 50 tags with a rule.
         *             <p>
         *             Tags can help you organize and categorize your resources. For more information, see <a href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Tagging.html">Tagging Your Amazon CloudWatch Resources</a> .
         *             <p>
         *             To be able to associate tags with a rule, you must have the <code>cloudwatch:TagResource</code> permission in addition to the <code>cloudwatch:PutInsightRule</code> permission.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tags(java.util.List<? extends java.lang.Object> tags) {
            this.tags = tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnInsightRuleProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnInsightRuleProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnInsightRuleProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnInsightRuleProps {
        private final java.lang.String ruleBody;
        private final java.lang.String ruleName;
        private final java.lang.String ruleState;
        private final java.lang.Object tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ruleBody = software.amazon.jsii.Kernel.get(this, "ruleBody", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.ruleName = software.amazon.jsii.Kernel.get(this, "ruleName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.ruleState = software.amazon.jsii.Kernel.get(this, "ruleState", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ruleBody = java.util.Objects.requireNonNull(builder.ruleBody, "ruleBody is required");
            this.ruleName = java.util.Objects.requireNonNull(builder.ruleName, "ruleName is required");
            this.ruleState = java.util.Objects.requireNonNull(builder.ruleState, "ruleState is required");
            this.tags = builder.tags;
        }

        @Override
        public final java.lang.String getRuleBody() {
            return this.ruleBody;
        }

        @Override
        public final java.lang.String getRuleName() {
            return this.ruleName;
        }

        @Override
        public final java.lang.String getRuleState() {
            return this.ruleState;
        }

        @Override
        public final java.lang.Object getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("ruleBody", om.valueToTree(this.getRuleBody()));
            data.set("ruleName", om.valueToTree(this.getRuleName()));
            data.set("ruleState", om.valueToTree(this.getRuleState()));
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudwatch.CfnInsightRuleProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnInsightRuleProps.Jsii$Proxy that = (CfnInsightRuleProps.Jsii$Proxy) o;

            if (!ruleBody.equals(that.ruleBody)) return false;
            if (!ruleName.equals(that.ruleName)) return false;
            if (!ruleState.equals(that.ruleState)) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.ruleBody.hashCode();
            result = 31 * result + (this.ruleName.hashCode());
            result = 31 * result + (this.ruleState.hashCode());
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}
